@@ -178,6 +178,16 @@ def ichol(
     ------
     ValueError
         If inappropriate parameter values were passed
+
+    Example
+    -------
+    >>> from pymatting import *
+    >>> import numpy as np
+    >>> from scipy.sparse import csc_matrix
+    >>> A = np.array([[2.0, 3.0], [3.0, 5.0]])
+    >>> cholesky_decomposition = ichol(csc_matrix(A))
+    >>> cholesky_decomposition(np.array([1.0, 2.0]))
+    array([-1.,  1.])
     """
 
     if isinstance(A, scipy.sparse.csr_matrix):
@@ -194,7 +204,7 @@ def ichol(
     assert m == n
 
     Lv = np.empty(max_nnz, dtype=np.float64)  # Values of non-zero elements of L
-    Lr = np.empty(max_nnz, dtype=np.int64)  # Values of non-zero elements of L
+    Lr = np.empty(max_nnz, dtype=np.int64)  # Row indices of non-zero elements of L
     Lp = np.zeros(
         n + 1, dtype=np.int64
     )  # Start(Lp[i]) and end(Lp[i+1]) index of L[:, i] in Lv
