@@ -3,22 +3,25 @@ from pymatting.util.kdtree import KDTree, knn
 from pymatting.util.boxfilter import boxfilter
 from pymatting.util.util import (
     apply_to_channels,
-    vec_vec_dot,
-    mat_vec_dot,
-    vec_vec_outer,
+    blend,
+    div_round_up,
+    fix_trimap,
+    grid_coordinates,
     isiterable,
     load_image,
-    save_image,
-    to_rgb8,
     make_grid,
-    show_images,
-    trimap_split,
-    blend,
-    stack_images,
+    mat_vec_dot,
     normalize_rows,
-    grid_coordinates,
-    sparse_conv_matrix,
-    weights_to_laplacian,
     normalize,
-    div_round_up,
+    row_sum,
+    save_image,
+    show_images,
+    sparse_conv_matrix,
+    sparse_conv_matrix_with_offsets,
+    stack_images,
+    to_rgb8,
+    trimap_split,
+    vec_vec_dot,
+    vec_vec_outer,
+    weights_to_laplacian,
 )
